import subprocess
import platform
import csv
from duckpy import Client
import GoogleLogo as gl
import time


def search_and_save(query, csv_filename):
    try:
        client = Client()
        results = client.search(query)

        url_set = set()  # Para almacenar las URL y evitar duplicados

        with open(csv_filename, 'a', newline='', encoding='utf-8') as file:
            writer = csv.writer(file)
            writer.writerow(["Búsqueda", "Título", "URL", "Descripción"])

            for result in results:
                title = result.title
                url = result.url
                description = result.description

                if url not in url_set:  # Solo se añade la fila si la URL no está en el conjunto
                    writer.writerow([query, title, url, description])
                    url_set.add(url)

        print(
            f'\n{gl.colors.FAIL}Archivo CSV "{csv_filename}" actualizado con los resultados de la búsqueda: {query}{gl.colors.ENDC}')
    except Exception as e:
        print(f'{gl.colors.FAIL}No hay resultados disponibles para la búsqueda: {query}{gl.colors.ENDC}')



if platform.system() == 'Windows':
    subprocess.call("cls", shell=True)
else:
    subprocess.call("clear", shell=True)

google_text = gl.google_text

UP = '\033[1A'
CLEAR = '\x1b[2K'

print(google_text)
print(
    f'\t{gl.colors.FAIL}Escribe {gl.colors.CYAN}"{gl.colors.GREEN}:historial{gl.colors.CYAN}"{gl.colors.FAIL} para ver tu historial de búsqueda.{gl.colors.ENDC}\n')

query_search = input(f'\tBúsqueda: {gl.colors.CYAN}')
phone = input(f'\tTeléfono: {gl.colors.CYAN}')
address = input(f'\tDirección: {gl.colors.CYAN}')

print(UP, end=CLEAR)
print(f'\t{gl.colors.FAIL}Resultados para: {gl.colors.CYAN}"{query_search}"{gl.colors.ENDC}')

csv_filename = f'{query_search}.csv'

if query_search == ':historial':
    history = open('search.history', 'r')
    print(f'\t{gl.colors.FAIL}Historial de búsqueda:\n{gl.colors.ENDC}')
    print(f'{gl.colors.CYAN}')
    index = 1
    for line in history:
        print(f'\t{index}. {line}')
        index += 1
    print(f'{gl.colors.ENDC}')
    history.close()
    garbage = input()
    exit()
else:
    history = open('search.history', 'a')
    history.write(f'{query_search}\n')
    history.close()

search_queries = [query_search,
                  f'"{query_search}" "{phone}"',
                  f'"{query_search}" -"{phone}"',
                  f'"{address}" "{phone}"',
                  f'"{address}" -"{phone}"',
                  f'"{query_search}" "{address}"',
                  f'"{query_search}" -"{address}"',
                  f'"{query_search}" "{phone}" -"{address}"',
                  f'"{query_search}" "{address}" -"{phone}"',
                  f'"{address}" -"{query_search}" "{phone}"',
                  f'"{phone}" -"{query_search}"',
                  f'"{phone}" -"{address}"',
                  f'"{phone}" -"{address}" -"{query_search}"',
                  f'"{address}" -"{query_search}" -"{phone}"']

for query in search_queries:
    search_and_save(query, csv_filename)
